@@ -10,9 +10,7 @@ class InterceptHandler(logging.Handler):
 
 
 LOGGING_LEVEL = logging.DEBUG  # if DEBUG else logging.INFO
-logging.basicConfig(
-    handlers=[InterceptHandler(level=LOGGING_LEVEL)], level=LOGGING_LEVEL
-)
+logging.basicConfig(handlers=[InterceptHandler(level=LOGGING_LEVEL)], level=LOGGING_LEVEL)
 log.configure(handlers=[{"sink": sys.stderr, "level": LOGGING_LEVEL}])
 
 
